# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as BaseProvider

# Russian jobs taken from the Wikipedia page
# https://ru.wikipedia.org/wiki/%D0%A1%D0%BF%D0%B8%D1%81%D0%BE%D0%BA_%D0%BF%D1%80%D0%BE%D1%84%D0%B5%D1%81%D1%81%D0%B8%D0%B9
class Provider(BaseProvider):
    jobs=["Авиадиспетчер",
"Авиатехник",
"Авиационный техник",
"Автогонщик",
"Автослесарь",
"Автоэлектрик",
"Агроном",
"Агроном по защите растений",
"Агроном-почвовед",
"Адвокат",
"Администратор базы данных",
"Аккумуляторщик",
"Актуарий",
"Актёр",
"Акушер",
"Аллерголог",
"Аналитик",
"Андролог",
"Антрополог",
"Артиллерист",
"Артист цирка",
"Археолог",
"Архивариус",
"Архитектор",
"Астроном",
"Астрофизик",
"Астрохимик",
"Бактериолог",
"Балерина",
"Балетмейстер",
"Банкир",
"Бармен",
"Баталер",
"Безработный",
"Библиотекарь",
"Библиотековед",
"Биоинженер",
"Биолог",
"Биофизик",
"Биохимик",
"Блоггер",
"Бондарь",
"Борт-инженер",
"Борт-механик",
"Борт-радист",
"Борт-стрелок",
"Бортинженер",
"Бортмеханик",
"Бортпроводник/стюард",
"Ботаник",
"Брейдер",
"Брокер",
"Булочник",
"Бульдозерист",
"Бухгалтер",
"Веб-интегратор",
"Веб-мастер",
"Веб-программист",
"Верстальщик",
"Ветеринар",
"Визажист",
"Виноградарь",
"Вирусолог",
"Водитель",
"Водолаз",
"Военно-полевой хирург",
"Военно-полевой хирург",
"Военнослужащий",
"Военный дознаватель",
"Военный консультант",
"Военный переводчик",
"Военный полицейский",
"Военный прокурор",
"Военный судья",
"Военный юрист",
"Воздухоплаватель",
"Вокалист",
"Воспитатель",
"Воспитатель",
"Востоковед",
"Врач МСЭК",
"Врач УЗ-диагностики",
"Врач скорой помощи",
"Врач функциональной диагностики",
"Выпускающий редактор",
"Гастроэнтеролог",
"Гематолог",
"Генетик",
"Генетик",
"Географ",
"Геодезист",
"Геолог",
"Гепатолог",
"Гидролог",
"Гинеколог",
"Гирудотерапевт",
"Гитарист",
"Гляциолог",
"Гомеопат",
"Горничная",
"Горнострелок",
"Горняк",
"Государственный исполнитель",
"Гранатомётчик",
"Грейдерист",
"Гренадер",
"Гример",
"Грузчик",
"Дворник",
"Декан",
"Декоратор",
"Дерматолог",
"Десантник",
"Детектив",
"Дефектолог",
"Диверсант",
"Диджей",
"Диетолог",
"Дизайнер",
"Дизайнер рекламы",
"Дизайнер-конструктор",
"Диктор",
"Дилер",
"Дипломат",
"Дипломат",
"Дипломатический работник",
"Дирижёр",
"Диспетчер",
"Дознаватель",
"Донкерман",
"Доула",
"Доярка",
"Драпировщик",
"Египтолог",
"Животновод",
"Жиловщик/Обвальщик",
"Журналист",
"Заряжающий",
"Заточник",
"Звукорежиссёр",
"Зенитчик",
"Златокузнец",
"Зоолог",
"Зоотехник",
"Издатель",
"Изобретатр",
"Иконописец",
"Иллюстратор",
"Имиджмейкер",
"Иммунолог",
"Инженер",
"Инженер",
"Инженер КИПиА",
"Инженер по Технике Безопасности",
"Инженер по механизации",
"Инженер-акустик",
"Инженер-взрывотехник",
"Инженер-гальваник",
"Инженер-гидравлик",
"Инженер-конструктор",
"Инженер-лаборант",
"Инженер-лесотехник",
"Инженер-механик",
"Инженер-системотехник",
"Инженер-строитель",
"Инженер-технолог",
"Инженер-физик",
"Инженер-химик",
"Инженер-электрик",
"Инженер-энергетик",
"Инкассатор",
"Интендант",
"Инфекционист",
"Искусствовед",
"Историк",
"Ихтиолог",
"Кабельщик",
"Кавалерист",
"Каменотёс",
"Канонир",
"Капитан судна",
"Каптенармус",
"Кардиолог",
"Кардиохирург",
"Каскадёр",
"Кассир",
"Квасник",
"Кинодраматург",
"Кинолог",
"Кинолог",
"Киномеханик",
"Кинооператор",
"Кинорежиссер",
"Кладовщик",
"Клинер",
"Кнопочник",
"Кодер",
"Кок",
"Командир",
"Комбайнер",
"Комендант",
"Коммерческий директор",
"Композитор",
"Конвоир",
"Кондитер",
"Кондитер",
"Кондуктор",
"Коневод",
"Контент-менеджер",
"Копирайтер",
"Корректировщик",
"Корректор",
"Косметолог",
"Космонавт",
"Крановщик",
"Кредитный консультант",
"Криптозоолог",
"Критик",
"Кровельщик",
"Кромкозакатчик",
"Крупье",
"Кузнец",
"Культуролог",
"Лаборант",
"Лекальщик",
"Лимфолог",
"Лингвист",
"Литейщик",
"Лифтёр",
"Логик",
"Логопед",
"Логопед",
"Лоцман",
"Лётчик",
"Лётчик",
"Маклер биржевой",
"Маляр",
"Маммолог",
"Манекенщица",
"Мануалист",
"Маркетолог",
"Маркитант",
"Маркшейдер",
"Массажист",
"Мастер маникюра",
"Мастер маникюра",
"Мастер педикюра",
"Математик",
"Машинист",
"Машинист локомотива",
"Машинистка",
"Медицинская сестра",
"Медник",
"Мелиоратор",
"Мельник",
"Менеджер",
"Менеджер по работе с клиентами",
"Мерчандайзер",
"Месильщик",
"Металлург",
"Метеоролог",
"Метранпаж",
"Метрдотель",
"Механизатор",
"Механик",
"Механик-Водитель",
"Миколог",
"Микробиолог",
"Министр",
"Модель",
"Модельер",
"Монтажник",
"Монтажник радиоэлектронной аппаратуры и приборов",
"Монтажник связи",
"Морской пехотинец",
"Моторист",
"Моторист",
"Мотострелок",
"Музыкант",
"Мусоропроводчик",
"Мусорщик",
"Мясник",
"Наводчик орудия",
"Налоговый инспектор",
"Нарколог",
"Начальник военного оркестра",
"Начальник гаупвахты",
"Начальник склада",
"Начальник службы",
"Начальник штаба",
"Невролог",
"Невропатолог",
"Нейрохирург",
"Неонатолог",
"Нефролог",
"Нотариус",
"Няня",
"Огнемётчик",
"Океанолог",
"Онколог",
"Оперативный работник",
"Оператор ПК",
"Оператор РЛС",
"Оператор вооружения",
"Оператор кино и телевидения",
"Оператор коллцентра",
"Оператор машинного доения",
"Операционист",
"Организатор свадеб",
"Орнитолог",
"Ортодонт",
"Ортопед",
"Особист",
"Оториноларинголог",
"Официант",
"Офтальмолог",
"Палеонтолог",
"Парикмахер",
"Парикмахер",
"Парфюмер",
"Пастух",
"Патологоанатом",
"Педагог",
"Педиатр",
"Пекарь",
"Переводчик",
"Переводчик",
"Переплётчик",
"Печатник",
"Писатель",
"Пластический хирург",
"Плиточник",
"Плотник",
"Повар",
"Повар",
"Пограничник",
"Подводник",
"Пожарный",
"Политолог",
"Полицейский",
"Портной",
"Портье",
"Постановщик трюков",
"Почтальон",
"Поэт",
"Правовед",
"Предприниматель",
"Преподаватель",
"Проводник",
"Программист",
"Программист",
"Продавец",
"Продавец",
"Продюсер",
"Прозектор",
"Проктолог",
"Прокурор",
"Промышленный альпинист",
"Промышленный альпинист",
"Проректор",
"Профпатолог",
"Проходчик",
"Психиатр",
"Психолог",
"Психоневропатолог",
"Психотерапевт",
"Пулемётчик",
"Пульмонолог",
"Пчеловод",
"Работник органов ЗАГСа",
"Радиолог",
"Радиомеханик",
"Радиотелефонист",
"Радист",
"Радист",
"Разведчик",
"Ракетчик",
"Распиловщик",
"Растениевод",
"Расточник",
"Реаниматолог",
"Ревматолог",
"Редактор",
"Режиссёр",
"Ректор",
"Релайтер",
"Религиовед",
"Рентгенолог",
"Реставратор",
"Рефлексотерапевт",
"Рихтовщик",
"Робототехник",
"Садовник",
"Садовод",
"Санитар",
"Сантехник",
"Сапожник",
"Сапёр",
"Сборщик",
"Сварщик",
"Связист",
"Священнослужитель",
"Секретчик",
"Сексолог",
"Сексопатолог",
"Семейный врач",
"Серпентолог",
"Сиделка",
"Системный администратор",
"Скорняк",
"Скотник",
"Скульптор",
"Следователь",
"Слесарь",
"Слесарь-механик",
"Сметчик",
"Снабженец",
"Снайпер",
"Сомелье",
"Сомнолог",
"Социолог",
"Специалист по клеточным технологиям",
"Специалист по стрижке овец",
"Спортивный врач",
"Сталевар",
"Старшина",
"Стилист",
"Столяр",
"Столяр-краснодеревщик",
"Стоматолог",
"Страховой агент",
"Стрелок",
"Стрелочник",
"Строитель",
"Судебный пристав",
"Судья",
"Сурдолог",
"Сурдопедагог",
"Сценарист",
"Сыровар",
"Табаковод",
"Табунщик",
"Таксист",
"Тальман",
"Таможенник",
"Танатолог",
"Танкист",
"Танцор",
"Татуировщик",
"Телеграфист",
"Тележурналист",
"Телемастер",
"Телефонист",
"Телохранитель",
"Теолог",
"Терапевт",
"Териолог",
"Тестировщик",
"Техник",
"Техник",
"Технолог",
"Типограф",
"Тифлопедагог",
"Товаровед",
"Токарь",
"Токарь-карусельщик",
"Токсиколог",
"Топограф",
"Торакальный хирург",
"Торговый представитель",
"Травматолог",
"Тракторист",
"Трансфузиолог",
"Трейдер",
"Тренд-вотчер",
"Тыловик",
"Тюремный надзиратель",
"Уборщик",
"Упаковщик",
"Уролог",
"Учитель",
"Учёный",
"Фальцовщик",
"Фармацевт",
"Фельдшер",
"Фельдшер",
"Фермер",
"Физик",
"Физиотерапевт",
"Филолог",
"Философ",
"Финансист",
"Финансист",
"Флеболог",
"Флорист",
"Флорист",
"Формовщик",
"Фортификатор",
"Фотограф",
"Фотомодель",
"Фрезеровщик",
"Фтизиатр",
"Фуражир",
"Футуролог",
"Химик",
"Химик",
"Химик-аналитик",
"Химик-контролер",
"Химик-технолог",
"Хирург",
"Хлебопёк",
"Хлебороб",
"Хлопокороб",
"Холодильщик",
"Хореограф",
"Художник",
"Художник по свету",
"Шахтёр",
"Швейцар",
"Швея",
"Шифровальщик",
"Шкипер",
"Шлифовщик",
"Шорник",
"Штукатур",
"Штурман",
"Эколог",
"Экономист",
"Экспедитор",
"Экспедитор на дальних поездках",
"Эксперт-криминалист",
"Электрик",
"Эндокринолог",
"Эндоскопист",
"Энтомолог",
"Эпидемиолог",
"Эфферентолог",
"Ювелир",
"Юрисконсульт",
"Юрист"]
