# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{last_name}}, {{first_name}}'
    )

    prefixes = (
        'Herra', 'hra', 'Rouva', 'rva', 'Tohtori', 'tri', 'prof.', 'arkkit.' 
    )

    suffixes = ('DI', 'PhD', 'MSc', 'BSc')

    first_names = (
        'Aake', 'Aapeli', 'Aapo', 'Aarne', 'Aarni', 'Aarno', 'Aaro', 'Aaron', 
        'Aarre', 'Aatami', 'Aatos', 'Aatto', 'Aatu', 'Ahti', 'Aimo', 'Aki', 
        'Aksel', 'Akseli', 'Aku', 'Alarik', 'Aleksanteri', 'Aleksi', 'Aleksis', 
        'Ali', 'Allan', 'Alpo', 'Altti', 'Alvar', 'Alvari', 'Anselmi', 'Anssi', 
        'Antero', 'Anton', 'Antti', 'Antton', 'Anttoni', 'Ari', 'Ari-Pekka', 
        'Armas', 'Arto', 'Arttu', 'Arttur', 'Artturi', 'Arvi', 'Arvo', 'Asko', 
        'Aslak', 'Asser', 'Asseri', 'Atte', 'Aukusti', 'Aulis', 'Auvo','Benjam', 
        'Benjamin', 'Daniel', 'Eeli', 'Eelis', 'Eemeli', 'Eemil', 'Eerik', 
        'Eerikki', 'Eero', 'Eetu', 'Eevert', 'Eevertti', 'Einari', 'Eino', 
        'Elias', 'Eliel', 'Eljas', 'Elmeri', 'Elmo', 'Ensio', 'Erkki', 'Erno', 
        'Esa', 'Esaias', 'Esko', 'Hannes', 'Hannu', 'Harri', 'Harry', 'Heikki', 
        'Heimo', 'Heino','Hemmo', 'Henri', 'Henrik', 'Henrikki', 'Herman', 
        'Hermanni', 'Huugo', 'Iikka', 'Iiro', 'Iisak', 'Iisakki', 'Iivari', 
        'Ilari', 'Ilkka', 'Ilmari', 'Ilmo', 'Ilpo', 'Immanuel', 'Into', 'Ismo', 
        'Isto', 'Jaakko', 'Jalmar', 'Jalmari', 'Jalo', 'Jami', 'Jani', 'Janne', 
        'Jari', 'Jari-Pekka', 'Jarkko', 'Jarmo', 'Jarno', 'Jasper', 'Jere', 
        'Jeremias', 'Jesse', 'Jimi', 'Joel', 'Johannes', 'Joni', 'Jonne', 
        'Joona', 'Joonas', 'Joonatan', 'Jooseppi', 'Jori', 'Jorma',  'Jouko', 
        'Jouni', 'Juha', 'Juha-Matti', 'Juha-Pekka', 'Juhana', 'Juhani', 'Juho', 
        'Jukka', 'Jukka-Pekka', 'Julius', 'Jussi', 'Juuso', 'Jyri', 'Jyrki', 
        'Kaapo', 'Kaarle', 'Kaarlo', 'Kai', 'Kaino', 'Kalervo', 'Kaleva', 
        'Kalevi', 'Kalle', 'Kari', 'Karri', 'Kasper', 'Kasperi', 'Kauko', 
        'Kauno', 'Keijo', 'Kimi', 'Kimmo', 'Klaus', 'Konsta', 'Konstantin', 
        'Kosti', 'Kristian', 'Kullervo', 'Kustaa', 'Kusti', 'Kyösti', 'Lari', 
        'Lasse', 'Lassi', 'Lauri', 'Leevi', 'Lenni', 'Leo', 'Luka', 'Luukas', 
        'Manu', 'Markku', 'Marko', 'Markus', 'Martti', 'Matias', 'Matti', 
        'Mauno', 'Maunu', 'Mauri', 'Miika', 'Miikka', 'Mika', 'Mikael', 'Mikko', 
        'Miko', 'Miro', 'Miska', 'Nestor', 'Nestori', 'Niilo', 'Niklas', 'Niko', 
        'Nikolai', 'Nuutti', 'Oiva', 'Olavi', 'Oliver', 'Olli', 'Olli-Pekka', 
        'Onni', 'Orvo', 'Oskar', 'Oskari', 'Osmo', 'Ossi', 'Ossian', 'Otso', 
        'Otto', 'Paavali', 'Paavo', 'Panu', 'Pasi', 'Paul', 'Pauli', 'Pekka', 
        'Pellervo', 'Pentti', 'Pertti', 'Perttu', 'Petri', 'Petter', 'Petteri', 
        'Pietari', 'Pyry', 'Päiviö', 'Rafael', 'Raimo', 'Raine', 'Rainer', 
        'Rami', 'Rasmus', 'Rauli', 'Rauni', 'Rauno', 'Reijo', 'Reima', 'Reino', 
        'Riku', 'Risto', 'Roni', 'Sakari', 'Saku', 'Salomon', 'Sami', 'Sampo', 
        'Sampsa', 'Samu', 'Samuel', 'Samuli', 'Santeri', 'Santtu', 'Sauli', 
        'Sebastian', 'Seppo', 'Severi', 'Simo', 'Soini', 'Sulevi', 'Sulo', 
        'Taavetti', 'Taavi', 'Taisto', 'Taito', 'Taneli', 'Tapani', 'Tapio', 
        'Tarmo', 'Tatu', 'Tauno', 'Teemu', 'Teijo', 'Tenho', 'Teppo', 
        'Terho', 'Tero', 'Teuvo', 'Timo', 'Tino', 'Toimi', 'Toivo', 'Tomi', 
        'Tommi', 'Toni', 'Topi', 'Topias', 'Torsti', 'Touko', 'Tuomas', 'Tuomo', 
        'Tuukka', 'Tuure', 'Ukko', 'Uljas', 'Untamo', 'Unto', 'Uolevi', 'Urho', 
        'Urpo', 'Usko', 'Uuno', 'Valde', 'Valdemar', 'Valentin', 'Valto', 
        'Valtteri', 'Waltteri', 'Veeti', 'Veijo', 'Veikka', 'Veikko', 'Veli', 
        'Veli-Matti', 'Veli-Pekka', 'Verner', 'Verneri', 'Vesa', 'Vieno', 
        'Vilhelmi', 'Vilho', 'Vili', 'Viljam', 'Viljami', 'Viljo', 'Ville', 
        'Voitto', 'Väinämö', 'Väinö', 'Ylermi', 'Yrjö', 'Aada', 'Aallotar', 
        'Aija', 'Aila', 'Aili', 'Aina', 'Aini', 'Aino', 'Aira', 'Airi', 
        'Aleksandra', 'Aliina', 'Aliisa', 'Alina', 'Alisa', 'Alli', 'Alma', 
        'Amalia', 'Amanda', 'Anastasia', 'Anelma', 'Anette', 'Anita', 'Anitta',
        'Anja', 'Anna', 'Anna-Kaisa', 'Anna-Leena', 'Anna-Liisa', 'Anna-Maija', 
        'Anna-Mari', 'Anna-Maria', 'Anne', 'Anne-Mari', 'Anne-Maria', 'Annele', 
        'Anneli', 'Anni', 'Anniina', 'Annika', 'Annikki', 'Annukka', 'Anu', 
        'Arja', 'Armi', 'Asta', 'Auli', 'Aulikki', 'Aune', 'Aura', 'Aurora', 
        'Bertta', 'Eedit', 'Eelin', 'Eerika', 'Eeva', 'Eeva-Liisa', 'Eevi', 
        'Eija', 'Eila', 'Eine', 'Eini', 'Eira', 'Elena', 'Eliina', 'Eliisa', 
        'Eliisabet', 'Elina', 'Elisa', 'Elisabet', 'Elise', 'Ella', 'Ellen', 
        'Elli', 'Elma', 'Elna', 'Elsa', 'Else', 'Elsi', 'Elvi', 'Elviira', 
        'Emilia', 'Emma', 'Emmi', 'Enni', 'Eriika', 'Erja', 'Essi', 
        'Ester', 'Esteri', 'Eveliina', 'Fanni', 'Hanna', 'Hanna-Leena', 
        'Hanna-Mari', 'Hanne', 'Hannele', 'Heidi', 'Heini', 'Heleena', 'Helena', 
        'Heli', 'Helinä', 'Heljä', 'Helka', 'Hellevi', 'Helli', 'Hellin', 
        'Hellä', 'Helmi', 'Helmiina', 'Helvi', 'Hely', 'Henna', 'Henrietta', 
        'Henriikka', 'Hertta', 'Heta', 'Hilda', 'Hilja', 'Hilkka', 'Hilla', 
        'Hillevi', 'Hilma', 'Iida', 'Iina', 'Iines', 'Iiris', 'Ilma', 'Ilmi', 
        'Ilona', 'Ilta', 'Impi', 'Inari', 'Inka', 'Inkeri', 'Ira', 'Irene', 
        'Irina', 'Iris', 'Irja', 'Irma', 'Irmeli', 'Isabella', 'Jaana', 'Jade', 
        'Janette', 'Janika', 'Janina', 'Janita', 'Janna', 'Jasmiina', 'Jasmin', 
        'Jemina', 'Jenna', 'Jenni', 'Joanna', 'Johanna', 'Jonna', 'Josefiina', 
        'Julia', 'Justiina', 'Jutta', 'Juulia', 'Kaarin', 'Kaarina', 'Kaija', 
        'Kaino', 'Kaisa', 'Kaisu', 'Kanerva', 'Karita', 'Karoliina','Katariina', 
        'Kati', 'Katja', 'Katri', 'Katriina', 'Kerttu', 'Kiia', 'Kirsi', 
        'Kirsi-Marja', 'Kirsti', 'Kreeta', 'Krista', 'Kristiina', 'Kustaava', 
        'Kyllikki', 'Lahja', 'Laila', 'Laimi', 'Laina', 'Laura', 'Lea', 'Leea', 
        'Leena', 'Leila', 'Lemmikki', 'Lemmitty', 'Lempi', 'Liisa', 'Liisi', 
        'Lilja', 'Lilli', 'Linda', 'Linnea', 'Lotta', 'Loviisa', 'Lumi','Lyydi', 
        'Lyydia', 'Lyyli', 'Maaret', 'Maaria', 'Maarit', 'Maija', 'Maija-Leena', 
        'Maija-Liisa', 'Maiju', 'Maila', 'Maire', 'Margareeta', 'Margareetta', 
        'Mari', 'Maria', 'Marianna', 'Marianne', 'Mariia', 'Mariitta', 'Marika', 
        'Marita', 'Maritta', 'Marja', 'Marja-Leena', 'Marja-Liisa', 
        'Marja-Riitta', 'Marja-Terttu', 'Marjaana', 'Marjatta', 'Marjo', 
        'Marjo-Riitta', 'Marjukka', 'Marjut', 'Marketta', 'Marleena', 'Martta', 
        'Matilda', 'Matleena', 'Meeri','Meri', 'Merja', 'Mervi', 'Miia','Miina', 
        'Mikaela', 'Milja', 'Milka', 'Milla','Mimosa', 'Minea', 'Minja','Minna', 
        'Minttu', 'Mira', 'Mirja', 'Mirjam','Mirjami', 'Mirka', 'Mirva','Moona', 
        'Naima', 'Natalia', 'Nea', 'Neea', 'Nella', 'Nelli', 'Netta', 'Niina', 
        'Noora', 'Oili', 'Olivia', 'Onerva', 'Oona', 'Orvokki', 'Outi', 'Paula', 
        'Pauliina','Peppi', 'Petra', 'Pihla', 'Piia', 'Pilvi', 'Pinja','Pirita', 
        'Piritta', 'Pirjo', 'Pirkko', 'Pirkko-Liisa', 'Päivi', 'Päivikki', 
        'Raakel', 'Raija', 'Raila', 'Raili', 'Raisa', 'Rauha', 'Rauni', 
        'Rebekka', 'Reeta', 'Reetta', 'Reija', 'Riikka', 'Riina', 'Riitta', 
        'Riitta-Liisa', 'Ritva', 'Ronja', 'Roosa', 'Saana', 'Saara', 'Saija', 
        'Saila', 'Saima', 'Saimi', 'Saini', 'Salla', 'Salli', 'Salme','Sanelma', 
        'Sanna', 'Sanni', 'Sara', 'Sari', 'Sarita', 'Satu', 'Seija', 'Selma', 
        'Senja', 'Senni', 'Siiri', 'Silja', 'Sini', 'Sinikka', 'Sirkka', 
        'Sirkka-Liisa', 'Sirkku', 'Sirpa', 'Sisko', 'Siviä', 'Sofia', 'Sohvi', 
        'Soile', 'Soili', 'Soilikki', 'Sointu', 'Sonja', 'Stiina', 'Suoma', 
        'Susan', 'Susanna','Susanne', 'Suvi', 'Sylvi', 'Sylvia', 'Säde','Taija', 
        'Taimi', 'Taina', 'Talvikki', 'Tanja', 'Tarja', 'Taru', 'Tea', 'Teija', 
        'Tekla', 'Tellervo', 'Teresa', 'Terhi', 'Terhikki', 'Terttu', 'Tiia', 
        'Tiina', 'Tilda', 'Titta', 'Toini', 'Tuija', 'Tuire', 'Tuovi', 'Tuuli', 
        'Tuulia', 'Tuulikki', 'Tytti', 'Tyyne', 'Tyyni', 'Ulla', 'Ulla-Maija', 
        'Unelma', 'Ursula', 'Valma', 'Valpuri', 'Vappu', 'Varpu', 'Veera', 
        'Vellamo', 'Venla', 'Vieno', 'Viivi', 'Vilhelmiina', 'Wilhelmiina', 
        'Vilja', 'Vilma', 'Wilma', 'Viola', 'Virpi', 'Virva', 'Virve', 'Vuokko'
    )

    last_names = (
        'Aalto', 'Aaltonen', 'Aarnio', 'Ahde', 'Aho', 'Ahopalo', 'Ahokas', 
        'Ahokangas', 'Ahola', 'Ahonen', 'Ahti', 'Ahtisaari', 'Alanen', 
        'Alasalmi', 'Alho', 'Annala', 'Anttila', 'Anttonen', 'Arajärvi', 'Aro', 
        'Aromaa', 'Asikainen', 'Askola', 'Astala', 'Asunmaa', 'Aura', 'Autio', 
        'Auvinen', 'Eerikäinen', 'Eerola', 'Einiö', 'Ekola', 'Elo', 'Elomaa', 
        'Eloranta', 'Elsilä', 'Ernamo', 'Erola', 'Eronen', 'Eskelinen','Eskola', 
        'Haanpää', 'Haapakoski', 'Haapasalo', 'Haataja', 'Hakala', 'Hannula', 
        'Harju', 'Harjula', 'Hartikainen', 'Hautala', 'Heikkilä', 'Heikkinen', 
        'Heinonen', 'Heiskanen', 'Helminen', 'Hietanen', 'Hiltunen','Hinkkanen', 
        'Hintikka', 'Hirsjärvi', 'Hirvelä', 'Hirvonen', 'Holappa', 'Hujanen', 
        'Huotari', 'Huovinen', 'Huttunen', 'Huusko', 'Huuskonen', 'Hynninen', 
        'Hyttinen', 'Häkkinen', 'Häkämies', 'Hämäläinen', 'Hänninen', 
        'Ihalainen', 'Ihamäki', 'Iivonen', 'Ijäs', 'Ikola', 'Ikonen','Ikäheimo', 
        'Ilmola', 'Ilmonen', 'Ilvonen', 'Immonen', 'Inkinen', 'Innanen', 
        'Isokangas', 'Isokallio', 'Isokoski', 'Isometsä', 'Isomäki', 'Isotalo', 
        'Issakainen', 'Itkonen', 'Itälä', 'Jaakkola', 'Jaakonsaari', 'Jaatinen',
        'Jalava', 'Jalkanen', 'Jalonen', 'Jantunen', 'Jarva', 'Jokela', 
        'Jokelainen', 'Jokinen', 'Juhola', 'Jukarainen', 'Jukola', 'Julkunen', 
        'Juntunen', 'Jussila', 'Jutila', 'Juva', 'Juvonen', 'Jylhä', 
        'Jäntti', 'Järvi', 'Järvilehto', 'Järvinen', 'Jääskeläinen', 
        'Kainulainen', 'Kallio', 'Kalliokoski', 'Kangas', 'Karhu','Karjalainen', 
        'Karonen', 'Karppanen', 'Karppinen', 'Kataisto', 'Kataja', 'Kemppainen', 
        'Keskinen', 'Keto', 'Ketola', 'Kettunen', 'Kinnunen', 'Kivelä', 
        'Kiviluoto', 'Kivinen', 'Kivistö', 'Koistinen', 'Koivula', 'Kokkonen', 
        'Korhonen', 'Korpela', 'Koskinen', 'Kosonen', 'Krouvi' 'Kulmala', 
        'Kunnas', 'Kuosmanen', 'Kuparinen', 'Kurkela', 'Kurkinen', 'Kuusela', 
        'Kuusisto', 'Laaksonen', 'Laatikainen', 'Lahtela', 'Lahti', 'Lahtinen', 
        'Laiho', 'Laine', 'Laitinen', 'Lamminen', 'Lampinen', 'Lankinen', 
        'Lappalainen', 'Larivaara', 'Lassila', 'Latvanen', 'Laukkanen', 
        'Laurila', 'Lauronen', 'Lehtinen', 'Lehto', 'Lehtonen', 'Leino', 
        'Leinonen', 'Lepistö', 'Leppälä', 'Leppänen', 'Leskinen', 'Lesonen', 
        'Liikanen', 'Lilja', 'Linna', 'Lipponen', 'Litmanen', 'Liukkonen', 
        'Loponen', 'Luhtanen', 'Lumme', 'Luostarinen', 'Makkonen', 'Manninen', 
        'Markku', 'Martikainen', 'Matikainen', 'Matinsalo', 'Mattila', 
        'Meriluoto', 'Miettunen', 'Mieto', 'Mikkola', 'Moilanen', 'Mustonen', 
        'Muukkonen', 'Myllylä', 'Myllyniemi', 'Mäenpää', 'Mäkelä', 'Mäki', 
        'Mäkilä', 'Mäkinen', 'Mänttäri', 'Mänty', 'Määttä', 'Naarajärvi', 
        'Narinen', 'Nenonen', 'Neuvonen', 'Nevala', 'Nevalainen', 'Niemelä', 
        'Niemi', 'Nieminen', 'Niinisalo', 'Niinistö', 'Niiranen', 'Nikkinen', 
        'Nikkola', 'Nikkonen', 'Nikula', 'Niskala', 'Nissinen', 'Nousiainen', 
        'Nummi', 'Numminen', 'Nurmela', 'Nurmi', 'Nurminen', 'Nuutinen', 
        'Nykänen', 'Närhi', 'Oikarinen', 'Oittinen', 'Ojakangas', 'Ojala', 
        'Ojalehto', 'Ojanen', 'Oksanen', 'Ollikainen', 'Ollila', 'Onnela', 
        'Oranen', 'Otila', 'Outila', 'Outinen', 'Ovaska', 'Paananen', 'Paasio', 
        'Pajari', 'Pale', 'Pakarinen', 'Parras', 'Parviainen', 'Pasanen', 
        'Pekkanen', 'Pekkala', 'Pelkonen', 'Peltola', 'Peltonen', 'Peltoniemi', 
        'Peltosaari', 'Pennanen', 'Pesonen', 'Pesälä', 'Petäjä', 'Pirhonen', 
        'Pirinen', 'Pitkänen', 'Pohjola', 'Pohjonen', 'Pokka', 'Porkka', 'Poso', 
        'Poutanen', 'Puikkonen', 'Pulkkinen', 'Purho', 'Pyysalo', 'Päätalo', 
        'Rahikainen', 'Rahkamo', 'Rahnasto', 'Rajala', 'Rannisto', 'Rantala', 
        'Rantanen', 'Rauhala', 'Rautakorpi', 'Rautanen', 'Rautavaara', 
        'Rautiainen', 'Rautio', 'Reinikainen', 'Rekunen', 'Repo', 'Repomem', 
        'Riihelä', 'Riihijärvi', 'Riikonen', 'Rinne', 'Rintala', 'Rissanen', 
        'Ritala', 'Roimola', 'Roivas', 'Ronni', 'Ruohonen', 'Ruutu', 'Ryttäri', 
        'Räikkönen', 'Räisänen', 'Räty', 'Saarela', 'Saari', 'Saarikoski', 
        'Saario', 'Saarinen', 'Saikkonen', 'Sainio', 'Saisio', 'Saksala', 
        'Salli', 'Sallinen', 'Salmi', 'Salminen', 'Salo', 'Salonen', 
        'Savolainen', 'Seppälä', 'Seppänen', 'Setälä', 'Sillanpää', 'Sinisalo', 
        'Sipilä', 'Sipinen', 'Sirkiä', 'Sirviö', 'Soikkeli', 'Soinio', 
        'Sormunen', 'Suhonen', 'Sulkanen', 'Suntila', 'Suominen', 'Supinen', 
        'Takala', 'Tammisto', 'Tamminen', 'Tanskanen', 'Taipale', 'Tarkka', 
        'Tenhunen', 'Tiainen', 'Tiihonen', 'Tiilikainen', 'Tikkanen', 'Timonen', 
        'Tirkkonen', 'Toivonen', 'Tuomi', 'Tuominen', 'Tuomioja', 'Tuomola', 
        'Turunen', 'Tuuri', 'Ukkola', 'Ulmanen', 'Uosukainen', 'Uotila', 
        'Uotinen', 'Uronen', 'Utriainen', 'Utrio', 'Uusitalo', 'Vainikainen', 
        'Vainio', 'Vanhala', 'Varala', 'Varis', 'Varvikko', 'Vatanen','Veintie', 
        'Venäläinen', 'Viitala', 'Viitanen', 'Viljanen', 'Vinni', 'Virolainen', 
        'Virtanen', 'Vitikka', 'Voutilainen', 'Vuolle', 'Vuorela', 'Vuorinen', 
        'Vuoristo', 'Välkkynen', 'Väänänen', 'Väätäinen', 'Ykspetäjä', 
        'Ylikangas', 'Ylikoski', 'Ylimäki', 'Ylinen', 'Yliniemi', 'Ylioja', 
        'Ylisuvanto', 'Ylitalo', 'Ylämäki', 'Ylänne', 'Ylätalo', 'Ylönen', 
        'Ylöstalo', 'Yrjälä', 'Yrjänä', 'Yrjänäinen', 'Yrjölä', 'Yrjönen'
    )

